@@ -7,6 +7,7 @@ import sensenet.importers
 tf = sensenet.importers.import_tensorflow()
 kl = sensenet.importers.import_keras_layers()
 
+from sensenet.layers.dropblock import DropBlock2D
 from sensenet.layers.utils import initializer_map, activation_function
 
 def get_units(params):
@@ -45,6 +46,8 @@ def dropout(params):
         return kl.Dropout(rate=rate, seed=42)
     elif dtype == 'alpha':
         return kl.AlphaDropout(rate=rate, seed=42)
+    elif dtype == 'block':
+        return DropBlock2D(rate=rate, seed=42)
     else:
         raise ValueError('"%s" is not a valid dropout type!' % dtype)
 
@@ -72,15 +75,24 @@ def avg_pool_2d(params):
     return kl.AveragePooling2D(pool_size, strides, padding)
 
 def padding_2d(params):
-    padding = [[int(p) for p in ps] for ps in params['padding']]
+    padding = tuple([tuple([int(p) for p in ps]) for ps in params['padding']])
     return kl.ZeroPadding2D(padding)
 
 def upsampling_2d(params):
-    return kl.UpSampling2D(params['size'])
+    if params.get('method', None) == 'bilinear':
+        return kl.UpSampling2D(params['size'], interpolation='bilinear')
+    else:
+        return kl.UpSampling2D(params['size'])
 
 def concatenate(params):
     return kl.Concatenate()
 
+def split_channels(params):
+    n = params['number_of_splits']
+    i = params['group_index']
+
+    return kl.Lambda(lambda x: tf.split(x, num_or_size_splits=n, axis=-1)[i])
+
 CORE_LAYERS = {
     'activation': activation,
     'average_pool_2d': avg_pool_2d,
@@ -93,5 +105,6 @@ CORE_LAYERS = {
     'global_max_pool_2d': global_max_pool_2d,
     'max_pool_2d': max_pool_2d,
     'padding_2d': padding_2d,
+    'split_channels': split_channels,
     'upsampling_2d': upsampling_2d
 }
