@@ -1,12 +1,15 @@
 import sensenet.importers
 tf = sensenet.importers.import_tensorflow()
 
+import math
+
 from sensenet.accessors import get_layer
+from sensenet.layers.yolo import YoloTrunk
 from sensenet.models.bounding_box import box_detector
 from sensenet.models.deepnet import deepnet_model
 from sensenet.models.settings import ensure_settings
 from sensenet.preprocess.preprocessor import Preprocessor
-from sensenet.pretrained import get_image_network, load_pretrained_weights
+from sensenet.pretrained import load_pretrained_weights, get_pretrained_network
 
 def image_model(network, input_settings):
     settings = ensure_settings(input_settings)
@@ -22,7 +25,7 @@ def image_model(network, input_settings):
     return model
 
 def pretrained_image_model(network_name, settings):
-    network = get_image_network(network_name)
+    network = get_pretrained_network(network_name)
     return image_model(network, settings)
 
 def io_for_extractor(model):
@@ -34,5 +37,11 @@ def image_feature_extractor(model):
     return tf.keras.Model(inputs=image_input, outputs=features)
 
 def image_layers(model):
-    preprocessor = get_layer(model, Preprocessor, None)
-    return preprocessor.get_image_layers()
+    try:
+        yolo_trunk = get_layer(model, YoloTrunk, None)
+        layers = yolo_trunk._trunk
+    except ValueError:
+        preprocessor = get_layer(model, Preprocessor, None)
+        layers = preprocessor.get_image_layers()
+
+    return layers
